==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_billboard_chain.js <==
var class_ogre_1_1_billboard_chain =
[
    [ "Element", "class_ogre_1_1_billboard_chain_1_1_element.html", "class_ogre_1_1_billboard_chain_1_1_element" ],
    [ "ElementList", "class_ogre_1_1_billboard_chain.html#a67c423725630e117cb31ebd9b231d523", null ],
    [ "TexCoordDirection", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0ee", [
      [ "TCD_U", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0eeab1390d0782b4780e43953c2b166b9cdc", null ],
      [ "TCD_V", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0eea8053985a9b153f4dea4ea70db8536782", null ]
    ] ],
    [ "BillboardChain", "class_ogre_1_1_billboard_chain.html#a6b5cba8ae02075702da9f7b2f07d3cc7", null ],
    [ "~BillboardChain", "class_ogre_1_1_billboard_chain.html#adb82bbc7c11e826039d850c1f911cdb7", null ],
    [ "setMaxChainElements", "class_ogre_1_1_billboard_chain.html#a9dfb228583ad5b4d5ddecb19e25b58cd", null ],
    [ "getMaxChainElements", "class_ogre_1_1_billboard_chain.html#ac336f36f7e1918987572d7b9120c1eef", null ],
    [ "setNumberOfChains", "class_ogre_1_1_billboard_chain.html#abcc3676539b5c73bc86039e0f4074124", null ],
    [ "getNumberOfChains", "class_ogre_1_1_billboard_chain.html#af6eb60f312cce1166cfab0fe3e7205f3", null ],
    [ "setUseTextureCoords", "class_ogre_1_1_billboard_chain.html#ae2873540c27dddd3062af468d6fa8d83", null ],
    [ "getUseTextureCoords", "class_ogre_1_1_billboard_chain.html#a18b96a4f14e7a49b21a423fe0e355891", null ],
    [ "setTextureCoordDirection", "class_ogre_1_1_billboard_chain.html#a7b15a6eea809c26455d3ba40c9fffc05", null ],
    [ "getTextureCoordDirection", "class_ogre_1_1_billboard_chain.html#aae77ad0e6c295ecf6ac088b1a9f2ce8c", null ],
    [ "setOtherTextureCoordRange", "class_ogre_1_1_billboard_chain.html#acd94644ca5489ade2cdf28c906c5f042", null ],
    [ "getOtherTextureCoordRange", "class_ogre_1_1_billboard_chain.html#acf9fcd373cb3b27521be9b4656534c8d", null ],
    [ "setUseVertexColours", "class_ogre_1_1_billboard_chain.html#a77eaefdad7be8d14b47e6e9f169b6617", null ],
    [ "getUseVertexColours", "class_ogre_1_1_billboard_chain.html#acfd03b8e57fe6a8b5196a270c6f1bdfd", null ],
    [ "setDynamic", "class_ogre_1_1_billboard_chain.html#ac1efa5463d2fedd8974af3e4b413b322", null ],
    [ "getDynamic", "class_ogre_1_1_billboard_chain.html#ac6fb10acf2de6d84b876957a7bdb76b4", null ],
    [ "addChainElement", "class_ogre_1_1_billboard_chain.html#a0a153e4f3a350248a53ab5e7382aae8d", null ],
    [ "removeChainElement", "class_ogre_1_1_billboard_chain.html#a86bd2530a15622dbb26aba8a9759b0d3", null ],
    [ "updateChainElement", "class_ogre_1_1_billboard_chain.html#ae3a6efc533be5309cf5274a7aa6a88db", null ],
    [ "getChainElement", "class_ogre_1_1_billboard_chain.html#afe208f1c230dc69b02e118417892f122", null ],
    [ "getNumChainElements", "class_ogre_1_1_billboard_chain.html#a4951ee94b8cdece4d6e7d3d0e6641167", null ],
    [ "clearChain", "class_ogre_1_1_billboard_chain.html#ae940e13fbd86e4f7555d613945b29f5a", null ],
    [ "clearAllChains", "class_ogre_1_1_billboard_chain.html#a38c7e0e727eede17350ca927202bc45c", null ],
    [ "setFaceCamera", "class_ogre_1_1_billboard_chain.html#a3039063ea009d11949489c1cd5a0d0be", null ],
    [ "getMaterialName", "class_ogre_1_1_billboard_chain.html#af4ef9118deb3a2b1aa6d17914fe45201", null ],
    [ "setMaterialName", "class_ogre_1_1_billboard_chain.html#afbfba68f0e99d3bac382b3c7b53e571c", null ],
    [ "getSquaredViewDepth", "class_ogre_1_1_billboard_chain.html#adeb5d707e6464f5695ba872f8d62ebdc", null ],
    [ "getBoundingRadius", "class_ogre_1_1_billboard_chain.html#a776f23095429fef83c662c0a3ce91f4e", null ],
    [ "getBoundingBox", "class_ogre_1_1_billboard_chain.html#a06d87c72d0462df1f904791771bcf1fb", null ],
    [ "getMaterial", "class_ogre_1_1_billboard_chain.html#aefbd62cbb981d3594afbeef9fb81d4a7", null ],
    [ "getMovableType", "class_ogre_1_1_billboard_chain.html#a1cb91c87260ea67e5de5d8ad972d3c9f", null ],
    [ "_updateRenderQueue", "class_ogre_1_1_billboard_chain.html#a1dcbc7ae7fd974fabccc83bf8f97bd31", null ],
    [ "getRenderOperation", "class_ogre_1_1_billboard_chain.html#a21555a72ccbad1a4845c80529e2ebd1e", null ],
    [ "preRender", "class_ogre_1_1_billboard_chain.html#af43447bc7d8a6090d856c008907cc2c0", null ],
    [ "getWorldTransforms", "class_ogre_1_1_billboard_chain.html#af8bb82ab6a1db3ffdf92eb800d99f447", null ],
    [ "getLights", "class_ogre_1_1_billboard_chain.html#a16501a62b436961e064f0889a304edf2", null ],
    [ "visitRenderables", "class_ogre_1_1_billboard_chain.html#a95381f721522dc92efc703bcb06c511e", null ]
];

==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_billboard_chain.js <==
var class_ogre_1_1_billboard_chain =
[
    [ "Element", "class_ogre_1_1_billboard_chain_1_1_element.html", "class_ogre_1_1_billboard_chain_1_1_element" ],
    [ "TexCoordDirection", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0ee", [
      [ "TCD_U", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0eeab1390d0782b4780e43953c2b166b9cdc", null ],
      [ "TCD_V", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0eea8053985a9b153f4dea4ea70db8536782", null ]
    ] ],
    [ "BillboardChain", "class_ogre_1_1_billboard_chain.html#a6b5cba8ae02075702da9f7b2f07d3cc7", null ],
    [ "~BillboardChain", "class_ogre_1_1_billboard_chain.html#adb82bbc7c11e826039d850c1f911cdb7", null ],
    [ "setMaxChainElements", "class_ogre_1_1_billboard_chain.html#a9dfb228583ad5b4d5ddecb19e25b58cd", null ],
    [ "getMaxChainElements", "class_ogre_1_1_billboard_chain.html#ac336f36f7e1918987572d7b9120c1eef", null ],
    [ "setNumberOfChains", "class_ogre_1_1_billboard_chain.html#abcc3676539b5c73bc86039e0f4074124", null ],
    [ "getNumberOfChains", "class_ogre_1_1_billboard_chain.html#af6eb60f312cce1166cfab0fe3e7205f3", null ],
    [ "setUseTextureCoords", "class_ogre_1_1_billboard_chain.html#ae2873540c27dddd3062af468d6fa8d83", null ],
    [ "getUseTextureCoords", "class_ogre_1_1_billboard_chain.html#a18b96a4f14e7a49b21a423fe0e355891", null ],
    [ "setTextureCoordDirection", "class_ogre_1_1_billboard_chain.html#a7b15a6eea809c26455d3ba40c9fffc05", null ],
    [ "getTextureCoordDirection", "class_ogre_1_1_billboard_chain.html#aae77ad0e6c295ecf6ac088b1a9f2ce8c", null ],
    [ "setOtherTextureCoordRange", "class_ogre_1_1_billboard_chain.html#acd94644ca5489ade2cdf28c906c5f042", null ],
    [ "getOtherTextureCoordRange", "class_ogre_1_1_billboard_chain.html#acf9fcd373cb3b27521be9b4656534c8d", null ],
    [ "setUseVertexColours", "class_ogre_1_1_billboard_chain.html#a77eaefdad7be8d14b47e6e9f169b6617", null ],
    [ "getUseVertexColours", "class_ogre_1_1_billboard_chain.html#acfd03b8e57fe6a8b5196a270c6f1bdfd", null ],
    [ "setAutoUpdate", "class_ogre_1_1_billboard_chain.html#a2b3de8a55c12a02a8a07906372c24f0a", null ],
    [ "getAutoUpdate", "class_ogre_1_1_billboard_chain.html#ac08f3a22eb7f8526824158877e41bff5", null ],
    [ "addChainElement", "class_ogre_1_1_billboard_chain.html#a0a153e4f3a350248a53ab5e7382aae8d", null ],
    [ "removeChainElement", "class_ogre_1_1_billboard_chain.html#a86bd2530a15622dbb26aba8a9759b0d3", null ],
    [ "updateChainElement", "class_ogre_1_1_billboard_chain.html#ae3a6efc533be5309cf5274a7aa6a88db", null ],
    [ "getChainElement", "class_ogre_1_1_billboard_chain.html#afe208f1c230dc69b02e118417892f122", null ],
    [ "getNumChainElements", "class_ogre_1_1_billboard_chain.html#a4951ee94b8cdece4d6e7d3d0e6641167", null ],
    [ "clearChain", "class_ogre_1_1_billboard_chain.html#ae940e13fbd86e4f7555d613945b29f5a", null ],
    [ "clearAllChains", "class_ogre_1_1_billboard_chain.html#a38c7e0e727eede17350ca927202bc45c", null ],
    [ "setFaceCamera", "class_ogre_1_1_billboard_chain.html#a3039063ea009d11949489c1cd5a0d0be", null ],
    [ "getMaterialName", "class_ogre_1_1_billboard_chain.html#af4ef9118deb3a2b1aa6d17914fe45201", null ],
    [ "setMaterialName", "class_ogre_1_1_billboard_chain.html#afbfba68f0e99d3bac382b3c7b53e571c", null ],
    [ "getSquaredViewDepth", "class_ogre_1_1_billboard_chain.html#a52cfadc750f094846260d435c4ba39dc", null ],
    [ "getBoundingRadius", "class_ogre_1_1_billboard_chain.html#a8422a07813467a2f5247134a3b082a63", null ],
    [ "getBoundingBox", "class_ogre_1_1_billboard_chain.html#a895c37a20cf12bc8d60ebf9402ddad4e", null ],
    [ "getMaterial", "class_ogre_1_1_billboard_chain.html#a7c217aee1ef230710cb0e97e3936e697", null ],
    [ "getMovableType", "class_ogre_1_1_billboard_chain.html#a2b80cfc5f391e51a2f1c8fade7d97f36", null ],
    [ "_updateRenderQueue", "class_ogre_1_1_billboard_chain.html#a0653cf3c578108cbc2efba177353c552", null ],
    [ "getRenderOperation", "class_ogre_1_1_billboard_chain.html#a56ae0f5fbc72c79a63ed35854ca7dd2e", null ],
    [ "preRender", "class_ogre_1_1_billboard_chain.html#af51ca4a5390cb127936373c419432313", null ],
    [ "getWorldTransforms", "class_ogre_1_1_billboard_chain.html#a4f3f3039677481e19f1d792d3908f56d", null ],
    [ "getLights", "class_ogre_1_1_billboard_chain.html#a7cf77f7b2fbd54dd12b9ab6e5db6df56", null ],
    [ "visitRenderables", "class_ogre_1_1_billboard_chain.html#a30be47f66404d9692021316c3823dd86", null ]
];
